@@ -1,6 +1,6 @@
 /*
  *
- * $Id: k3bdatajob.cpp 507450 2006-02-09 09:01:24Z trueg $
+ * $Id: k3bdatajob.cpp 528555 2006-04-11 12:17:49Z trueg $
  * Copyright (C) 2003 Sebastian Trueg <trueg@k3b.org>
  *
  * This file is part of the K3b project.
@@ -134,6 +134,17 @@ void K3bDataJob::start()
 
   emit newTask( i18n("Preparing data") );
 
+  d->doc->prepareFilenames();
+  if( d->doc->needToCutFilenames() ) {
+    if( !questionYesNo( i18n("Some filenames need to be shortened due to the %1 char restriction "
+			     "of the Joliet extensions. Continue anyway?")
+			.arg( d->doc->isoOptions().jolietLong() ? 103 : 64 ) ) ) {
+      emit canceled();
+      emit finished( false );
+      return;
+    }
+  }
+  
   if( d->usedMultiSessionMode == K3bDataDoc::AUTO && !d->doc->onlyCreateImages() )
     determineMultiSessionMode();
   else
@@ -885,4 +896,10 @@ QString K3bDataJob::jobDetails() const
       .arg(KIO::convertSize( d->doc->size() ));
 }
 
+
+bool K3bDataJob::hasBeenCanceled() const
+{
+  return d->canceled;
+}
+
 #include "k3bdatajob.moc"
