@@ -1,6 +1,6 @@
 /*
  *
- * $Id: k3bisoimager.cpp 487838 2005-12-12 08:53:11Z trueg $
+ * $Id: k3bisoimager.cpp 531385 2006-04-19 08:20:20Z trueg $
  * Copyright (C) 2003 Sebastian Trueg <trueg@k3b.org>
  *
  * This file is part of the K3b project.
@@ -443,17 +443,6 @@ void K3bIsoImager::start()
   kdDebug() << s << endl << flush;
   emit debuggingOutput("mkisofs command:", s);
 
-  if( m_doc->needToCutFilenames() ) {
-    if( !questionYesNo( i18n("Some filenames need to be shortened due to the %1 char restriction "
-			     "of the Joliet extensions. Continue anyway?")
-			.arg( m_doc->isoOptions().jolietLong() ? 103 : 64 ) ) ) {
-      emit canceled();
-      emit finished( false );
-      cleanup();
-      return;
-    }
-  }
-  
   if( !m_process->start( KProcess::NotifyOnExit, KProcess::AllOutput) ) {
     // something went wrong when starting the program
     // it "should" be the executable
@@ -1012,10 +1001,10 @@ QString K3bIsoImager::dummyDir( K3bDirItem* dir )
   name += QString::number( dir->sortWeight() );
 
   bool perm = false;
-  struct stat64 statBuf;
+  k3b_struct_stat statBuf;
   if( !dir->localPath().isEmpty() ) {
     // permissions
-    if( ::stat64( QFile::encodeName( dir->localPath() ), &statBuf ) == 0 ) {
+    if( k3b_stat( QFile::encodeName( dir->localPath() ), &statBuf ) == 0 ) {
       name += "_";
       name += QString::number( statBuf.st_uid );
       name += "_";
