@@ -1,6 +1,6 @@
 /*
  *
- * $Id: k3bcdrecordwriter.cpp 420842 2005-06-01 14:33:00Z coles $
+ * $Id: k3bcdrecordwriter.cpp 526655 2006-04-05 10:04:16Z trueg $
  * Copyright (C) 2003 Sebastian Trueg <trueg@k3b.org>
  *
  * This file is part of the K3b project.
@@ -616,7 +616,7 @@ void K3bCdrecordWriter::slotStdLine( const QString& line )
   else if( line.contains("Medium Error") ) {
     m_cdrecordError = MEDIUM_ERROR;
   }
-  else if( line.startsWith( "Error trying to open" ) && line.contains( "(Device or resource busy)" ) ) {
+  else if( line.startsWith( "Error trying to open" ) && line.contains( "Device or resource busy" ) ) {
     m_cdrecordError = DEVICE_BUSY;
   }
   else {
