@@ -1,6 +1,6 @@
 /*
  *
- * $Id: k3bmixedjob.cpp 509861 2006-02-15 18:35:29Z trueg $
+ * $Id: k3bmixedjob.cpp 528555 2006-04-11 12:17:49Z trueg $
  * Copyright (C) 2003 Sebastian Trueg <trueg@k3b.org>
  *
  * This file is part of the K3b project.
@@ -142,7 +142,18 @@ void K3bMixedJob::start()
   m_doc->audioDoc()->setHideFirstTrack( false );   // unsupported
   m_doc->dataDoc()->setBurner( m_doc->burner() );  // so the isoImager can read ms data
 
-  emit newTask( i18n("Preparing write process") );
+  emit newTask( i18n("Preparing data") );
+
+  m_doc->dataDoc()->prepareFilenames();
+  if( m_doc->dataDoc()->needToCutFilenames() ) {
+    if( !questionYesNo( i18n("Some filenames need to be shortened due to the %1 char restriction "
+			     "of the Joliet extensions. Continue anyway?")
+			.arg( m_doc->dataDoc()->isoOptions().jolietLong() ? 103 : 64 ) ) ) {
+      emit canceled();
+      emit finished( false );
+      return;
+    }
+  }
 
   determineWritingMode();
 
