@@ -1,6 +1,6 @@
 /*
  *
- * $Id: k3bdiskinfodetector.cpp,v 1.53.2.1 2005/02/24 08:15:57 trueg Exp $
+ * $Id$
  * Copyright (C) 2003 Sebastian Trueg <trueg@k3b.org>
  *
  * This file is part of the K3b project.
@@ -37,72 +37,71 @@ public:
       runningHandler(0) {
   }
 
-  CdDevice* device;
-  DiskInfo info;
-  NextGenerationDiskInfo ngDiskInfo;
+  Device* device;
+  DiskInfo diskInfo;
   Toc toc;
-  AlbumCdText cdText;
+  CdText cdText;
   K3bIso9660* iso9660;
 
   bool isVideoDvd;
   bool isVideoCd;
 
-  K3bCdDevice::DeviceHandler* runningHandler;
+  K3bDevice::DeviceHandler* runningHandler;
 };
 
 
 
-K3bCdDevice::DiskInfoDetector::DiskInfoDetector( QObject* parent )
+K3bDevice::DiskInfoDetector::DiskInfoDetector( QObject* parent )
   : QObject( parent )
 {
   d = new Private();
 }
 
 
-K3bCdDevice::DiskInfoDetector::~DiskInfoDetector()
+K3bDevice::DiskInfoDetector::~DiskInfoDetector()
 {
   delete d->iso9660;
   delete d;
 }
 
 
-K3bCdDevice::CdDevice* K3bCdDevice::DiskInfoDetector::device() const
+K3bDevice::Device* K3bDevice::DiskInfoDetector::device() const
 {
   return d->device;
 }
 
 
-// const K3bCdDevice::DiskInfo& K3bCdDevice::DiskInfoDetector::diskInfo() const
+// const K3bDevice::DiskInfo& K3bDevice::DiskInfoDetector::diskInfo() const
 // {
 //   return d->info;
 // }
 
 
-const K3bCdDevice::NextGenerationDiskInfo& K3bCdDevice::DiskInfoDetector::ngDiskInfo() const
+const K3bDevice::DiskInfo& K3bDevice::DiskInfoDetector::diskInfo() const
 {
-  return d->ngDiskInfo;
+  return d->diskInfo;
 }
 
 
-const K3bCdDevice::AlbumCdText& K3bCdDevice::DiskInfoDetector::cdText() const
+const K3bDevice::CdText& K3bDevice::DiskInfoDetector::cdText() const
 {
   return d->cdText;
 }
 
 
-const K3bCdDevice::Toc& K3bCdDevice::DiskInfoDetector::toc() const
+const K3bDevice::Toc& K3bDevice::DiskInfoDetector::toc() const
 {
   return d->toc;
 }
 
 
-const K3bIso9660* K3bCdDevice::DiskInfoDetector::iso9660() const
+const K3bIso9660* K3bDevice::DiskInfoDetector::iso9660() const
 {
   return d->iso9660;
 }
 
 
-void K3bCdDevice::DiskInfoDetector::detect( CdDevice* device )
+void K3bDevice::DiskInfoDetector::detect( Device* device )
 {
   if( !device ) {
     kdDebug() << "(K3bDiskInfoDetector) detect should really not be called with NULL!" << endl;
@@ -123,23 +122,23 @@ void K3bCdDevice::DiskInfoDetector::detect( CdDevice* device )
   if( d->runningHandler )
     d->runningHandler->disconnect( this );
 
-  connect( (d->runningHandler = K3bCdDevice::diskInfo(d->device)),
-           SIGNAL(finished(K3bCdDevice::DeviceHandler *)),
+  connect( (d->runningHandler = K3bDevice::diskInfo(d->device)),
+           SIGNAL(finished(K3bDevice::DeviceHandler *)),
            this,
-	   SLOT(slotDeviceHandlerFinished(K3bCdDevice::DeviceHandler *)) );
+	   SLOT(slotDeviceHandlerFinished(K3bDevice::DeviceHandler *)) );
 }
 
 
-void K3bCdDevice::DiskInfoDetector::finish(bool success)
+void K3bDevice::DiskInfoDetector::finish(bool success)
 {
   //  d->info.valid=success;
   emit diskInfoReady(this);
 }
 
 
-void K3bCdDevice::DiskInfoDetector::fetchExtraInfo()
+void K3bDevice::DiskInfoDetector::fetchExtraInfo()
 {
-  kdDebug() << "(K3bCdDevice::DiskInfoDetector) fetchExtraInfo()" << endl;
+  kdDebug() << "(K3bDevice::DiskInfoDetector) fetchExtraInfo()" << endl;
 
   d->toc.calculateDiscId();
   //  d->device->indexScan( d->toc );
@@ -150,13 +149,13 @@ void K3bCdDevice::DiskInfoDetector::fetchExtraInfo()
   // FIXME: blank DVD+RW media already has a track so this method tries to open ido9660...
   //
 
-  if( d->toc.contentType() == K3bCdDevice::DATA ||
-      d->toc.contentType() == K3bCdDevice::MIXED ) {
-    if( d->device->open() != -1 ) {
+  if( d->toc.contentType() == K3bDevice::DATA ||
+      d->toc.contentType() == K3bDevice::MIXED ) {
+    if( d->device->open() ) {
 
       unsigned long startSec = 0;
 
-      if( d->ngDiskInfo.numSessions() > 1 ) {
+      if( d->diskInfo.numSessions() > 1 ) {
 	// We use the last data track
 	// this way we get the latest session on a ms cd
 	Toc::const_iterator it = toc().end();
@@ -189,7 +188,7 @@ void K3bCdDevice::DiskInfoDetector::fetchExtraInfo()
 // 	d->info.isoApplicationId = d->iso9660->primaryDescriptor().applicationId;
 	
 
-	if( K3bCdDevice::isDvdMedia( d->ngDiskInfo.mediaType() ) ) {
+	if( K3bDevice::isDvdMedia( d->diskInfo.mediaType() ) ) {
 	  d->isVideoDvd = false;
 
 	  // We check for the VIDEO_TS directory and at least one .IFO file
@@ -256,18 +255,22 @@ void K3bCdDevice::DiskInfoDetector::fetchExtraInfo()
 }
 
 
-void K3bCdDevice::DiskInfoDetector::slotDeviceHandlerFinished( K3bCdDevice::DeviceHandler *handler)
+void K3bDevice::DiskInfoDetector::slotDeviceHandlerFinished( K3bDevice::DeviceHandler *handler)
 {
   d->runningHandler = 0;
 
-  kdDebug() << "(K3bCdDevice::DiskInfoDetector) slotDeviceHandlerFinished()" << endl;
+  kdDebug() << "(K3bDevice::DiskInfoDetector) slotDeviceHandlerFinished()" << endl;
 
   bool success = handler->success();
   if( success ) {
     //    d->info = handler->diskInfo();
-    d->ngDiskInfo = handler->ngDiskInfo();
-    d->ngDiskInfo.debug();
+    d->diskInfo = handler->diskInfo();
+    d->diskInfo.debug();
     d->cdText = handler->cdText();
+
+    // some debugging
+    CdText x( d->cdText.rawPackData() );
+
     d->toc = handler->toc();
     fetchExtraInfo();
   }
