@@ -1,6 +1,6 @@
 /*
  *
- * $Id: k3bfileview.h 412285 2005-05-11 09:02:46Z trueg $
+ * $Id: k3bfileview.h 442567 2005-08-03 07:42:59Z trueg $
  * Copyright (C) 2003 Sebastian Trueg <trueg@k3b.org>
  *
  * This file is part of the K3b project.
@@ -54,7 +54,6 @@ class K3bFileView : public K3bCdContentsView
 
  public slots:
   void setDir( const QString& );
-  void slotAddFilesToProject();
   void saveConfig( KConfig* c );
   void readConfig( KConfig* c );
   void setAutoUpdate( bool );
@@ -69,7 +68,6 @@ class K3bFileView : public K3bCdContentsView
  private slots:
   void slotFilterChanged();
   void slotFileHighlighted( const KFileItem* item );
-  void slotCheckActions();
 };
 
 
