@@ -1,6 +1,6 @@
 /*
  *
- * $Id: k3bcdcopydialog.cpp 430267 2005-06-30 17:52:11Z trueg $
+ * $Id: k3bcdcopydialog.cpp 471081 2005-10-16 10:55:47Z trueg $
  * Copyright (C) 2003 Sebastian Trueg <trueg@k3b.org>
  *                    Klaus-Dieter Krannich <kd@k3b.org>
  *
@@ -204,6 +204,8 @@ K3bCdCopyDialog::K3bCdCopyDialog( QWidget *parent, const char *name, bool modal
   connect( m_comboCopyMode, SIGNAL(activated(int)), this, SLOT(slotToggleAll()) );
   connect( m_checkReadCdText, SIGNAL(toggled(bool)), this, SLOT(slotToggleAll()) );
 
+  connect( k3bcore->deviceManager(), SIGNAL(changed(K3bDevice::DeviceManager*)),
+	   this, SLOT(slotDeviceManagerChanged(K3bDevice::DeviceManager*)) );
 
   QToolTip::add( m_checkIgnoreReadErrors, i18n("Skip unreadable sectors") );
   QToolTip::add( m_checkNoCorrection, i18n("Disable the source drive's error correction") );
@@ -385,7 +387,8 @@ void K3bCdCopyDialog::slotToggleAll()
 
    m_writingModeWidget->setEnabled( !m_checkOnlyCreateImage->isChecked() );
 
-   m_buttonStart->setEnabled( dev || m_checkOnlyCreateImage->isChecked() );
+   m_buttonStart->setEnabled( m_comboSourceDevice->selectedDevice() && 
+			      (dev || m_checkOnlyCreateImage->isChecked()) );
 }
 
 
@@ -470,4 +473,10 @@ void K3bCdCopyDialog::loadK3bDefaults()
   slotToggleAll();
 }
 
+
+void K3bCdCopyDialog::slotDeviceManagerChanged( K3bDevice::DeviceManager* dm )
+{
+  m_comboSourceDevice->refreshDevices( dm->cdReader() );
+}
+
 #include "k3bcdcopydialog.moc"
