@@ -1,6 +1,6 @@
 /*
  *
- * $Id: k3bcdimagewritingdialog.cpp 487843 2005-12-12 09:30:25Z trueg $
+ * $Id: k3bcdimagewritingdialog.cpp 549696 2006-06-09 14:38:47Z trueg $
  * Copyright (C) 2003 Sebastian Trueg <trueg@k3b.org>
  *
  * This file is part of the K3b project.
@@ -828,7 +828,6 @@ void K3bCdImageWritingDialog::slotMd5JobPercent( int p )
 void K3bCdImageWritingDialog::slotMd5JobFinished( bool success )
 {
   if( success ) {
-    d->md5SumItem->setPixmap( 0, SmallIcon( "ok") );
     d->md5SumItem->setText( 1, d->md5Job->hexDigest() );
   }
   else {
@@ -852,7 +851,7 @@ void K3bCdImageWritingDialog::slotMd5SumCompare()
 						   &ok,
 						   this );
   if( ok ) {
-    if( md5sumToCompare.utf8() == d->md5Job->hexDigest() )
+    if( md5sumToCompare.lower().utf8() == d->md5Job->hexDigest().lower() )
       KMessageBox::information( this, i18n("The MD5 Sum of %1 equals the specified.").arg(imagePath()),
 				i18n("MD5 Sums Equal") );
     else
